@@ -322,19 +322,18 @@ bar
 ]
 """
 
-from subprocess import Popen, PIPE, STDOUT
-from threading import Thread
-from tempfile import NamedTemporaryFile
 from json import dumps
 from pathlib import Path
+from subprocess import PIPE, STDOUT, Popen
+from tempfile import NamedTemporaryFile
+from threading import Thread
 
 STRING_NOT_INSTALLED = "not installed"
 STRING_MISSING_FORMAT = "missing format"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     config = {}
@@ -364,19 +363,23 @@ class Py3status:
         self.config.update({"out_to_x": False, "out_to_console": True})
         self.separator = "|SEPARATOR|"  # must be upper
 
-        # make an output.
+        # make an output
         config = dumps(self.config, separators=(",", "=")).replace('"', "")
         text = self.separator.join([f"${{{x}}}" for x in conky_placeholders])
         tmp = f"conky.config = {config}\nconky.text = [[{text}]]"
 
         # write tmp output to '/tmp/py3status-conky_*', make a command
-        self.tmpfile = NamedTemporaryFile(
-            prefix="py3status_conky-", suffix=".conf", delete=False
-        )
+        self.tmpfile = NamedTemporaryFile(prefix="py3status_conky-", suffix=".conf", delete=False)
         self.tmpfile.write(str.encode(tmp))
         self.tmpfile.close()
         self.conky_command = f"conky -c {self.tmpfile.name}".split()
 
+        # skip invalid conky errors
+        self.invalid_conky_errors = [
+            "conky: invalid setting of type 'table'",
+            "conky: FOUND:",
+        ]
+
         # thread
         self.line = ""
         self.error = None
@@ -387,7 +390,7 @@ class Py3status:
 
     def _cleanup(self):
         self.process.kill()
-        Path(self.tmpfile).unlink()
+        Path(self.tmpfile.name).unlink()
         self.py3.update()
 
     def _start_loop(self):
@@ -396,6 +399,8 @@ class Py3status:
             while True:
                 line = self.process.stdout.readline().decode()
                 if self.process.poll() is not None or "conky:" in line:
+                    if any(x in line for x in self.invalid_conky_errors):
+                        continue
                     raise Exception(line)
                 if self.line != line:
                     self.line = line
